@@ -1,5 +1,7 @@
 package Selenium::Remote::RemoteConnection;
-$Selenium::Remote::RemoteConnection::VERSION = '0.18';
+$Selenium::Remote::RemoteConnection::VERSION = '0.1801';
+#ABSTRACT: Connect to a selenium server
+
 use Moo;
 use Try::Tiny;
 use LWP::UserAgent;
@@ -149,44 +151,75 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Selenium::Remote::RemoteConnection - Connect to a selenium server
 
 =head1 VERSION
 
-version 0.18
+version 0.1801
 
 =head1 SEE ALSO
 
-For more information about Selenium, visit the website at
-L<http://code.google.com/p/selenium/>.
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Selenium::Remote::Driver|Selenium::Remote::Driver>
+
+=back
 
 =head1 BUGS
 
-The Selenium issue tracking system is available online at
-L<http://github.com/gempesaw/Selenium-Remote-Driver/issues>.
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/gempesaw/Selenium-Remote-Driver/issues
 
-=head1 CURRENT MAINTAINER
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
-Daniel Gempesaw C<< <gempesaw@gmail.com> >>
+=head1 AUTHORS
 
-=head1 AUTHOR
+=over 4
 
-Perl Bindings for Selenium Remote Driver by Aditya Ivaturi C<< <ivaturi@gmail.com> >>
+=item *
 
-=head1 LICENSE
+Aditya Ivaturi <ivaturi@gmail.com>
+
+=item *
+
+Daniel Gempesaw <gempesaw@gmail.com>
+
+=item *
+
+Luke Closs <cpan@5thplane.com>
+
+=item *
+
+Mark Stosberg <mark@stosberg.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
+Copyright (c) 2014 Daniel Gempesaw
+
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
-     http://www.apache.org/licenses/LICENSE-2.0
+http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
+
+=cut
